==> kdepim-addons_17.12.3.orig.tar.xz: kdepim-addons-17.12.3/examples/apps/coisceim/eventselectorwidget.h <==
/*
    This file is part of Akonadi.

    Copyright (c) 2011 Stephen Kelly <steveire@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
    USA.
*/

#ifndef EVENTSELECTORWIDGET_H
#define EVENTSELECTORWIDGET_H

#include <QDialog>
#include <AkonadiCore/Item>

class QTreeView;

namespace CalendarSupport {
class IncidenceViewer;
}

class EventSelectorDialog : public QDialog
{
    Q_OBJECT
public:
    explicit EventSelectorDialog(QWidget *parent = nullptr, Qt::WindowFlags f = 0);

    Akonadi::Item selectedItem();

private:
    QTreeView *m_view;
};

class EventSelectorWidget : public QWidget
{
    Q_OBJECT
public:
    explicit EventSelectorWidget(QWidget *parent = nullptr, Qt::WindowFlags f = 0);

    void clear();

Q_SIGNALS:
    void selected(const Akonadi::Item &item);

private Q_SLOTS:
    void selectTrip();

private:
    CalendarSupport::IncidenceViewer *m_browser;
};

#endif

==> kdepim-addons_19.12.3.orig.tar.xz: kdepim-addons-19.12.3/examples/apps/coisceim/eventselectorwidget.h <==
/*
    This file is part of Akonadi.

    Copyright (c) 2011 Stephen Kelly <steveire@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
    USA.
*/

#ifndef EVENTSELECTORWIDGET_H
#define EVENTSELECTORWIDGET_H

#include <QDialog>
#include <AkonadiCore/Item>

class QTreeView;

namespace CalendarSupport {
class IncidenceViewer;
}

class EventSelectorDialog : public QDialog
{
    Q_OBJECT
public:
    explicit EventSelectorDialog(QWidget *parent = nullptr, Qt::WindowFlags f = {});

    Akonadi::Item selectedItem();

private:
    QTreeView *m_view;
};

class EventSelectorWidget : public QWidget
{
    Q_OBJECT
public:
    explicit EventSelectorWidget(QWidget *parent = nullptr, Qt::WindowFlags f = {});

    void clear();

Q_SIGNALS:
    void selected(const Akonadi::Item &item);

private Q_SLOTS:
    void selectTrip();

private:
    CalendarSupport::IncidenceViewer *m_browser;
};

#endif
